==> haskell-git-lfs-1.1.1-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 git-lfs
version:              1.1.1
visibility:           public
id:                   git-lfs-1.1.1-78z6MPSvjMjDXEi3TbPeUB
key:                  git-lfs-1.1.1-78z6MPSvjMjDXEi3TbPeUB
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  eaca0a593f0e7b5e1b79190cf6598ccd
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.0.1/site-local/git-lfs-1.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/git-lfs-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/git-lfs-1.1.1
hs-libraries:         HSgit-lfs-1.1.1-78z6MPSvjMjDXEi3TbPeUB
depends:
    aeson-1.5.6.0-BNspgXAzKp6CkIs2quQxij base-4.15.0.0
    bytestring-0.10.12.1
    case-insensitive-1.2.1.0-C62erXxWyCP2CSc0oj6vPA containers-0.6.4.1
    http-client-0.7.8-JF57Uz6k97nLmqDGQ4NJhe
    http-types-0.12.3-5OQIfWo1epLjmhOdBpvcY
    network-uri-2.6.4.1-BLO7J2ZupQZ1TNm4gnLLSm text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-git-lfs-1.1.1-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 git-lfs
version:              1.1.1
visibility:           public
id:                   git-lfs-1.1.1-5rYuC5jtij24dyW4BTsVcV
key:                  git-lfs-1.1.1-5rYuC5jtij24dyW4BTsVcV
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  69144158d55fe7fd14d3bf23f33af7e1
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.0.1/site-local/git-lfs-1.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/git-lfs-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/git-lfs-1.1.1
hs-libraries:         HSgit-lfs-1.1.1-5rYuC5jtij24dyW4BTsVcV
depends:
    aeson-1.5.6.0-9o8y4QVT0ed6zIp89KPO7i base-4.15.0.0
    bytestring-0.10.12.1
    case-insensitive-1.2.1.0-LsJJ5284Amp7gbCwTtqWK9 containers-0.6.4.1
    http-client-0.7.8-25QqChzgp0q9j6ealXbwz
    http-types-0.12.3-EsczPCiHgMfDgCbh8KUGRq
    network-uri-2.6.4.1-HkoRuB3ykvaLxStim29dr5 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
